#include "FujichanClient.h"
#define UPDATE_INTERVAL 60*5 // 更新間隔[秒]

float temperature   = 0; // 気温（単位は[°C]）
int   funkaLevel    = 0; // 噴火警戒レベル
float precipitation = 0; // 降水量（単位は[mm/h]）

void setup() {
  pinMode(speaker, OUTPUT);
  led.setup();
  Serial.begin(115200);
  Serial.println("START");

  // Wi-Fiへ接続する関数
  connect();
  // Webサーバからデータを取得する関数
  update(&temperature, &funkaLevel, &precipitation);
}

void loop() {
  if ( Serial.available() > 0 ) {
    float val = Serial.parseFloat();
    // Setting for Temperature
    if ( val < 1000 ) {
      temperature = val;
      /* 気温が更新された時の処理．ここから */
      
      led.fadeOut(500);
      RGBColor c = temperature2Color( val );
      Serial.print(c.r);
      Serial.print(",");
      Serial.print(c.g);
      Serial.print(",");
      Serial.println(c.b);
      led.fadeIn(c.r, c.g, c.b, 500);

      /* ここまで */
    }
    // Setting Volcano Activity Level
    else if ( val >= 1000 && val < 2000) {
      funkaLevel = val - 1000.0;
      /* 噴火警戒レべルが更新された時の処理．ここから */

      // 噴火警戒レベルによってブザーを鳴らす
      if(funkaLevel > 3){
        for(int i=0; i<funkaLevel; i++) {
          tone(speaker, 1000);
          delay(400);
          noTone(speaker);
          delay(100);
        }
      }

      /* ここまで */
    }
    // Setting for rain[mm] sound
    else if ( 2000 <= val && val < 3000 ) {
      precipitation = val - 2000.0;
      /* 降水量が更新された時の処理．ここから */


      
      /* ここまで */
    }
    // Command for manual update
    else if ( (int)val == 3001 ) {
      update(&temperature, &funkaLevel, &precipitation);
    }
    // Command for turn off all LEDs and Sound
    else if ( (int)val == 4001 ) {
      precipitation = 0.0;
      led.fadeOut(500);
      return;
    }
    else {
      return;
    }
  }
  
  makeRainSound(precipitation);
  delay(1);
  if ( !metro(UPDATE_INTERVAL) ) {
    return;
  }
  update(&temperature, &funkaLevel, &precipitation);
}

static unsigned long int time = 0;
bool metro(int seconds) {
  if ( (millis() - time) > seconds * 1000 ) {
    time = millis();
    return true;
  }
  else {
    return false;
  }
}

/* Suda 2018/08/19 */
